----------------------------------------------
-- Beispielskript zur AEK 17 im Herbst 2014 --
-- Autor: Bernd Jungbluth                   --
-- Keine Gewhrleistung, keine Haftung      --		
----------------------------------------------

USE AEK;
GO

-- Gespeicherte Prozedur anlegen
IF object_id('pSelectKontakt') Is Not Null 
BEGIN
	DROP PROC dbo.pSelectKontakt;
END
GO
CREATE PROC dbo.pSelectKontakt @KontaktID int
AS
SET NOCOUNT ON;

SELECT	dbo.Kontakte.KontaktID, Firma, Nachname, Vorname
FROM	dbo.Kontakte INNER JOIN dbo.Ansprechpartner 
		ON dbo.Kontakte.KontaktID = dbo.Ansprechpartner.KontaktID
WHERE	dbo.Kontakte.KontaktID = @KontaktID;
GO

-- Plancache fr AEK-Datenbank leeren
DBCC FLUSHPROCINDB (7)
GO

-- AdHoc-Abfragen ausfhren
USE AEK;
GO
SELECT	dbo.Kontakte.KontaktID, Firma, Nachname, Vorname
FROM	dbo.Kontakte INNER JOIN dbo.Ansprechpartner 
		ON dbo.Kontakte.KontaktID = dbo.Ansprechpartner.KontaktID
WHERE	dbo.Kontakte.KontaktID = 1;
GO
SELECT	dbo.Kontakte.KontaktID, Firma, Nachname, Vorname
FROM	dbo.Kontakte INNER JOIN dbo.Ansprechpartner 
		ON dbo.Kontakte.KontaktID = dbo.Ansprechpartner.KontaktID
WHERE	dbo.Kontakte.KontaktID = 2;
GO
SELECT	dbo.Kontakte.KontaktID, Firma, Nachname, Vorname
FROM	dbo.Kontakte INNER JOIN dbo.Ansprechpartner 
		ON dbo.Kontakte.KontaktID = dbo.Ansprechpartner.KontaktID
WHERE	dbo.Kontakte.KontaktID = 3;
GO

-- Ein Blick in den Plancache
USE master;
GO
SELECT	
		db_name(s.dbid) As Datenbank, size_in_bytes,
		UseCounts As AnzahlVerwendung,
		cacheobjtype As Plantyp, objtype As Abfragetyp,
		text as SqlAnweisung
FROM	
		sys.dm_exec_cached_plans c
		CROSS APPLY sys.dm_exec_sql_text(plan_handle) s
WHERE 
		s.dbid = 7
ORDER BY 
		objtype, usecounts DESC;

-- Erneutes Ausfhren von SQL-Anweisungen
USE AEK;
GO
SELECT	dbo.Kontakte.KontaktID, Firma, Nachname, Vorname
FROM	dbo.Kontakte INNER JOIN dbo.Ansprechpartner 
		ON dbo.Kontakte.KontaktID = dbo.Ansprechpartner.KontaktID
WHERE	dbo.Kontakte.KontaktID = 1;
GO
SELECT	dbo.Kontakte.KontaktID, Firma, Nachname, Vorname
FROM	dbo.Kontakte INNER JOIN dbo.Ansprechpartner 
		ON dbo.Kontakte.KontaktID = dbo.Ansprechpartner.KontaktID
WHERE	dbo.Kontakte.KontaktID =  3;
GO

-- Ein Blick in den Plancache
USE master;
GO
SELECT	
		db_name(s.dbid) As Datenbank, size_in_bytes,
		UseCounts As AnzahlVerwendung,
		cacheobjtype As Plantyp, objtype As Abfragetyp,
		text as SqlAnweisung
FROM	
		sys.dm_exec_cached_plans c
		CROSS APPLY sys.dm_exec_sql_text(plan_handle) s
WHERE 
		s.dbid = 7
ORDER BY 
		objtype, usecounts DESC;

-- Gespeicherte Prozedur ausfhren
USE AEK;
GO
EXEC dbo.pSelectKontakt 1;
GO
EXEC dbo.pSelectKontakt 2;
GO
EXEC dbo.pSelectKontakt 3;
GO

-- Ein erneuter Blick in den Plancache
USE master;
GO
SELECT	
		db_name(s.dbid) As Datenbank, size_in_bytes,
		UseCounts As AnzahlVerwendung,
		cacheobjtype As Plantyp, objtype As Abfragetyp,
		text as SqlAnweisung, s.dbid
FROM	
		sys.dm_exec_cached_plans c
		CROSS APPLY sys.dm_exec_sql_text(plan_handle)  s
WHERE 
		s.dbid = 7
ORDER BY 
		objtype, usecounts DESC;

-- Erneutes Ausfhren der Gespeicherten Prozdur
USE AEK;
GO
EXEC dbo.pSelectKontakt 1;
GO
EXEC dbo.pSelectKontakt 3;
GO

-- Ein erneuter Blick in den Plancache
USE master;
GO
SELECT	
		db_name(s.dbid) As Datenbank, size_in_bytes,
		UseCounts As AnzahlVerwendung,
		cacheobjtype As Plantyp, objtype As Abfragetyp,
		text as SqlAnweisung, s.dbid
FROM	
		sys.dm_exec_cached_plans c
		CROSS APPLY sys.dm_exec_sql_text(plan_handle)  s
WHERE 
		s.dbid = 7
ORDER BY 
		objtype, usecounts DESC;

-- Vergleich des Speicherbedarfs
USE master;
GO
SELECT	SUM(CASE WHEN objtype = 'Adhoc' THEN size_in_bytes END) As Speicherbedarf_AdHoc,
		SUM(CASE WHEN objtype = 'Proc' THEN size_in_bytes END) As Speicherbedarf_Proc
FROM	sys.dm_exec_cached_plans CROSS APPLY sys.dm_exec_sql_text(plan_handle) s 
WHERE	s.dbid = 7;